Drupal.casetrackerTime = Drupal.casetrackerTime || {};
Drupal.casetrackerTime.execution = Drupal.casetrackerTime.execution || {};

Drupal.behaviors.dynamicTimeTracker = function (context) {
 $('form.node-timing', context).each(function () {
    Drupal.casetrackerTime.execution = new Drupal.casetrackerTime(this);
  });
};

/**
 * A time timer switch object
 */
Drupal.casetrackerTime = function (form) {
  var timer = this;
  this.form = form;
  this.nid = $('#'+ form.id +' input[name="nid"]').attr('value');
  this.uid = $('#'+ form.id +' input[name="uid"]').attr('value');
  this.button = $('#'+ form.id +' input[type="submit"]');
  this.url = Drupal.settings.casetracker_time.url + '/' + this.nid + '/' + this.uid;
  this.counter = $('#'+ form.id +' .counter');
  this.context = '';
  this.prev_context = '';
  this.status  = 'stopped';
  this.case_status_id = '';
  this.select_status = $('select[name*="case_status_id"]');
  this.div_status = $('div.status');
  this.status_list = Drupal.settings.casetracker_time.status_list;
  this.status_onchange = false;
  this.initialize();
  this.last_keydown = 0;
  this.writing_timeout = 10;

  //$('body').bind('mousemove keydown', function(event) {
  $('form').bind('keydown', function(event) {
    // TODO: implement writing timing for standard text inputs
  });

  // Identify Keydown for CKEDITOR instances
  for ( instance in CKEDITOR.instances ) {
    CKEDITOR.instances[instance].on('instanceReady', function() {
      this.document.on('keydown', function() {
        // TODO: detect possible noise actions
        if ( timer.context != 'writing' && timer.status == 'ongoing' ) {
          // stop timer
          timer.updateContext('writing');
          timer.switchTracking();
        }
        else if ( timer.last_keydown == 0 ) {
          // change the context
          timer.updateContext('writing');
          timer.startTracking();
          // TODO: take into account that the nid Case could be distinct
          // if is that the case we could ask the user if resume the previous timer
        }

        timer.last_keydown = Math.round((new Date()).getTime() / 1000); 
      });    
    });
  }

  setInterval (function() { timer.initialize(); }, 20000);
};

/**
 * Initialize the time timer
 */
Drupal.casetrackerTime.prototype.initialize = function () {
  var timer = this;

  $.ajax({
    type: "GET",
    url: timer.url,
    dataType: 'json',
    success: function (status) {
      $(timer.counter).countdown({compact:true});
      $(timer.counter).countdown('change', 'since', -status['time']).countdown('resume');
      timer.getStatus(status);
    },
    error: function (xmlhttp) {
      alert(Drupal.ahahError(xmlhttp, timer.startURL));
    }
  });
};

Drupal.casetrackerTime.prototype.getStatus = function(status_data) {
  var timer = this;
  timer.status = status_data['status'];
  timer.case_status_id = status_data['case_status_id'];

  if (timer.status == 'ongoing') {
    var ut = Math.round((new Date()).getTime() / 1000); 
    if ( timer.last_keydown > 0 && ut - timer.writing_timeout > timer.last_keydown ) {
      timer.last_keydown = 0;

      if ( timer.prev_context ) {
        timer.updateContext(timer.prev_context);
        timer.prev_context = ''
        timer.switchTracking();
      }
      else {
        timer.stopTracking();
      }
    }

    $(timer.button).unbind().bind('click', function(event) {
        timer.updateContext('');
        timer.stopTracking();
        event.preventDefault();
    });
    $(timer.counter).countdown('resume');
    $(timer.button).val(Drupal.t('Stop'));
    timer.initStatus(); 
    $(timer.form).removeClass('node-timer-start').addClass('node-timer-stop');
  }
  else {
    $(timer.button).unbind().bind('click', function(event) {
        timer.updateContext('executing');
        timer.startTracking();
        event.preventDefault();
    });
    $(timer.counter).countdown('pause');
    $(timer.button).val(Drupal.t('Start'));
    timer.initStatus(); 
    $(timer.form).removeClass('node-timer-stop').addClass('node-timer-start');
  }
}


/**
 * Starts timing
 */
Drupal.casetrackerTime.prototype.startTracking = function () {
  var timer = this;

  timer.status = 'ongoing';

  // Ajax GET request for starting time timer
  $.ajax({
    type: "GET",
    url: timer.url + '/start/' + timer.context,
    dataType: 'json',
    success: function (status) {
      $(timer.counter).countdown('change', {since: -status['time']}).countdown('resume');
      $(timer.button).val(Drupal.t('Stop'));
      $(timer.form).removeClass('node-timer-start').addClass('node-timer-stop');
      timer.getStatus(status);
    },
    error: function (xmlhttp) {
      alert(Drupal.ahahError(xmlhttp, timer.startURL));
    }
  });
};

/**
 * Stops timing
 */
Drupal.casetrackerTime.prototype.stopTracking = function () {
  var timer = this;

  timer.status = 'stop';

  $.ajax({
    type: "GET",
    url: timer.url + '/stop',
    dataType: 'json',
    success: function (status) {
      $(timer.counter).countdown('change', {since: -status['time']}).countdown('pause');
      $(timer.button).val(Drupal.t('Start'));
      $(timer.form).removeClass('node-timer-stop').addClass('node-timer-start');
      timer.getStatus(status);
    },
    error: function (xmlhttp) {
      alert(Drupal.ahahError(xmlhttp, timer.startURL));
    }
  });
};

/**
 * Switch timing
 */
Drupal.casetrackerTime.prototype.switchTracking = function () {
  var timer = this;

  timer.status = 'stop';

  // Ajax GET request for starting time timer
  $.ajax({
    type: "GET",
    url: timer.url + '/stop/' + timer.context,
    dataType: 'json',
    success: function (status) {
      $(timer.counter).countdown('change', {since: -status['time']}).countdown('resume');
      $(timer.button).val(Drupal.t('Stop'));
      $(timer.form).removeClass('node-timer-start').addClass('node-timer-stop');
      timer.startTracking();
    },
    error: function (xmlhttp) {
      alert(Drupal.ahahError(xmlhttp, timer.startURL));
    }
  });
};

/**
 * Update context and keep the timer running
 */
Drupal.casetrackerTime.prototype.updateContext = function(context) {
  var timer = this;

  if ( !context ) {
    timer.prev_context = '';
    this.context = '';
  }
  else {
    if ( this.context != '' && this.context != context ) {
      timer.prev_context = this.context;
    }

    timer.context = context;
  }
}

/**
 * Initialize case status
 */
Drupal.casetrackerTime.prototype.initStatus = function() {
  var timer = this;

  // if the status is changed by hand we don't sync with remote status
  // could be that somebody is writing a comment and changing it.
  $(timer.select_status).bind('change', function() {
    timer.status_onchange = true;
  });

  if ( !timer.status_onchange ) {
    $(timer.select_status).val(timer.case_status_id);
  }

  $(timer.div_status).html(timer.status_list[timer.case_status_id]);
};
